==> jackrabbit-oak-1.22.23-src.zip: jackrabbit-oak-1.22.23/oak-search/src/main/java/org/apache/jackrabbit/oak/plugins/index/search/spi/binary/BlobByteSource.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.jackrabbit.oak.plugins.index.search.spi.binary;

import java.io.IOException;
import java.io.InputStream;

import com.google.common.io.ByteSource;
import org.apache.jackrabbit.oak.api.Blob;

/**
 * {@link ByteSource} extension to work with Oak {@link Blob}s
 */
public final class BlobByteSource extends ByteSource {
    private final Blob blob;

    public BlobByteSource(Blob blob) {
        this.blob = blob;
    }

    @Override
    public InputStream openStream() throws IOException {
        return blob.getNewStream();
    }

    @Override
    public long size() throws IOException {
        return blob.length();
    }

    @Override
    public boolean isEmpty() throws IOException {
        return blob.length() == 0;
    }
}

==> jackrabbit-oak-1.68.0-src.zip: jackrabbit-oak-1.68.0/oak-search/src/main/java/org/apache/jackrabbit/oak/plugins/index/search/spi/binary/BlobByteSource.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.jackrabbit.oak.plugins.index.search.spi.binary;

import java.io.IOException;
import java.io.InputStream;

import org.apache.jackrabbit.guava.common.io.ByteSource;
import org.apache.jackrabbit.oak.api.Blob;

/**
 * {@link ByteSource} extension to work with Oak {@link Blob}s
 */
public final class BlobByteSource extends ByteSource {
    private final Blob blob;

    public BlobByteSource(Blob blob) {
        this.blob = blob;
    }

    @Override
    public InputStream openStream() throws IOException {
        return blob.getNewStream();
    }

    @Override
    public long size() throws IOException {
        return blob.length();
    }

    @Override
    public boolean isEmpty() throws IOException {
        return blob.length() == 0;
    }
}
